<?php
/*
Plugin Name: YITH WooCommerce Multi Vendor Premium Kupon Support
Plugin URI: http://yithemes.com/themes/plugins/yith-woocommerce-product-vendors/
Description: Support for Kupon Theme
Author: YITHEMES
Version: 1.0.0
Author URI: http://yithemes.com/
*/
/*
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly 

add_action( 'init', 'yith_wcmv_kupon_support', 20 );
add_action( 'init', 'yith_wcmv_remove_report_abuse_link_from_page', 20 );
add_action( 'widgets_init', 'yith_wcmv_register_report_abuse_widget' );
add_action( 'wp_enqueue_scripts', 'yith_wcmv_wp_enqueue_scripts_for_report_abuse', 30 );

if( ! function_exists( 'yith_wcmv_kupon_support' ) ){
    function yith_wcmv_kupon_support(){
        if( function_exists( 'YITH_Vendors' ) ){
            $frontend = YITH_Vendors()->frontend;
            remove_action( 'woocommerce_after_shop_loop_item', array( $frontend, 'woocommerce_template_vendor_name'), 6 );
            remove_action( 'woocommerce_single_product_summary', array( $frontend, 'woocommerce_template_vendor_name' ), 5 );
            add_filter('azexo_entry_field', 'yith_wcmv_template_vendor_name', 15, 2);
        }
    }
}

if( ! function_exists( 'yith_wcmv_template_vendor_name' ) ){
    function yith_wcmv_template_vendor_name( $output, $name ){
        global $product;
        if (class_exists('WooCommerce') && $product) {
            switch ($name) {
                case 'price_offer':
                    if (class_exists('YITH_Vendors') ) {
                        $frontend = YITH_Vendors()->frontend;

                        if( ! empty( $frontend ) ){
                            ob_start();
                            $frontend->woocommerce_template_vendor_name();
                            return ob_get_clean();
                        }
                    }
                    break;
            }
        }

        return $output;
    }
}

if( ! class_exists( 'YITH_Report_Abuse_Vendors_Widget' ) ){
    class YITH_Report_Abuse_Vendors_Widget extends WP_Widget{

        public function __construct() {
            parent::__construct( false, __( 'YITH Vendor Report Abuse Link', 'yith-woocommerce-product-vendors' ) );
        }

        public function widget($args, $instance) {
        	if( ! function_exists( 'YITH_Vendors' ) ){
        		return false;
        	}

            $frontend = YITH_Vendors()->frontend;
            if( ! empty( $frontend ) &&  method_exists( $frontend, 'add_report_abuse_link' ) ){
                extract( $args );

                echo '<div class="yith-wcmv-report-abuse-wrapper">';

                $title = html_entity_decode( apply_filters( 'widget_title', isset( $instance['title'] ) ? $instance['title'] : '' ) );

                if ( ! empty( $title ) ) {
                    echo  '<h4 class="widget-title yith-wcmv-report-abuse product_title entry-title">' . $title . '</h4>';
                }

                $frontend->add_report_abuse_link();

                echo '</div>';
            }
        }

        public function form( $instance ) {
            $defaults = array(
                'title' => __( 'Contact support and report abuse', 'yith-woocommerce-product-vendors' ),
            );

            $instance = wp_parse_args( (array) $instance, $defaults );

            ?>

            <p>
                <label>
                    <strong><?php _e( 'Title', 'yith-woocommerce-ajax-navigation' ) ?>:</strong><br />
                    <input class="widefat" type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
                </label>
            </p>

            <?php
        }

        public function update( $new_instance, $old_instance ) {
            $instance           = $old_instance;
            $instance['title']  = strip_tags( $new_instance['title'] );
            return $instance;
        }
    }
}

if( ! function_exists( 'yith_wcmv_register_report_abuse_widget' ) ){
    function yith_wcmv_register_report_abuse_widget() {
        register_widget( 'YITH_Report_Abuse_Vendors_Widget' );
    }
}

if( ! function_exists( 'yith_wcmv_remove_report_abuse_link_from_page' ) ){
    function yith_wcmv_remove_report_abuse_link_from_page(){
    	if( function_exists( 'YITH_Vendors' ) ){
    		$frontend = YITH_Vendors()->frontend;

	        if( ! empty( $frontend ) ){
	            $action   = YITH_Vendors()->is_wc_2_7_or_greather ? 'woocommerce_single_product_summary' : 'woocommerce_product_thumbnails';
	            $priority = YITH_Vendors()->is_wc_2_7_or_greather ? 60 : 30;
	            remove_action( $action, array( $frontend, 'add_report_abuse_link' ), $priority);
	        }
    	}
    }
}

if( ! function_exists( 'yith_wcmv_wp_enqueue_scripts_for_report_abuse' ) ){
	function yith_wcmv_wp_enqueue_scripts_for_report_abuse(){
		$stylesheet_file_name = plugins_url( '/', __FILE__ ) . 'yith-wcmv-kupon-style.css';
		
		wp_register_style( 'yith-wc-product-vendors-report-abuse-widget', $stylesheet_file_name, array( 'yith-wc-product-vendors' ), '1.0.0' );

		if( is_singular( 'product' ) ){
			wp_enqueue_style( 'yith-wc-product-vendors-report-abuse-widget' );
		}
	}
}